@@ -19,16 +19,13 @@
 # TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 # SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
+import base64
 import os
 import uuid
 
 from mailjet_rest import Client
 
 from majormode.perseus.email.email_service import EmailServiceBase
-from majormode.perseus.model.email import Email
-
-# api_key = '05d79dffe420a58a58c1438cb4dc667f'
-# api_secret = '03979eb145eb1ecadec29718fe198942'
 
 
 class MailjetService(EmailServiceBase):
@@ -37,6 +34,29 @@ class MailjetService(EmailServiceBase):
     ENVIRONMENT_KEY_NAME_MAILJET_API_KEY = 'MAILJET_API_KEY'
     ENVIRONMENT_KEY_NAME_MAILJET_API_SECRET = 'MAILJET_API_SECRET'
 
+    @staticmethod
+    def __build_attached_file_item(file_path_name: str) -> dict:
+        with open(file_path_name) as fd:
+            file_content = fd.read()
+            file_base64_content = base64.b64encode(file_content.encode())
+            file_name = os.path.basename(file_path_name)
+
+            attached_file_item = {
+                "Content-type": "text/plain",  # @todo: Implement binary file support
+                "Filename": file_name,
+                "content": file_base64_content,
+            }
+
+            return attached_file_item
+
+    @classmethod
+    def __build_attached_file_items(cls, attached_files: list[str]) -> list[dict]:
+        attached_file_items = [
+            cls.__build_attached_file_item(file_path_name)
+            for file_path_name in  attached_files
+        ]
+        return attached_file_items
+
     def __init__(
             self,
             api_key=None,
@@ -56,8 +76,8 @@ class MailjetService(EmailServiceBase):
             auth=(api_key, api_secret),
             version=api_version or self.DEFAULT_MAILJET_VERSION)
 
-    @staticmethod
-    def __build_mailjet_data(emails):
+    @classmethod
+    def __build_mailjet_data(cls, emails):
         data = {
             'Messages': [
                 {
@@ -75,7 +95,8 @@ class MailjetService(EmailServiceBase):
                     'Subject': email.subject,
                     'TextPart': email.text_content,
                     'HTMLPart': email.html_content,
-                    'CustomID': uuid.uuid4().hex
+                    'CustomID': uuid.uuid4().hex,
+                    'Attachments': email.attached_files and cls.__build_attached_file_item(email.attached_files),
                 }
                 for email in emails
             ]
